@@ -84,12 +84,8 @@
 #endif // HAVE_SYS_INOTIFY_H
 
 Q_DECLARE_LOGGING_CATEGORY(KDIRWATCH)
-#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
 // logging category for this framework, default: log stuff >= warning
 Q_LOGGING_CATEGORY(KDIRWATCH, "kf5.kcoreaddons.kdirwatch", QtWarningMsg)
-#else
-Q_LOGGING_CATEGORY(KDIRWATCH, "kf5.kcoreaddons.kdirwatch")
-#endif
 
 // set this to true for much more verbose debug output
 static const bool s_verboseDebug = false;
@@ -177,7 +173,11 @@ KDirWatchPrivate::KDirWatchPrivate()
       statEntries(0),
       delayRemove(false),
       rescan_all(false),
-      rescan_timer()
+      rescan_timer(),
+#if HAVE_SYS_INOTIFY_H
+      mSn(Q_NULLPTR),
+#endif
+      _isStopped(false)
 {
     timer.setObjectName(QStringLiteral("KDirWatchPrivate::timer"));
     connect(&timer, SIGNAL(timeout()), this, SLOT(slotRescan()));
@@ -1881,8 +1881,6 @@ KDirWatch::KDirWatch(QObject *parent)
     const int counter = nameCounter.fetchAndAddRelaxed(1); // returns the old value
     setObjectName(QStringLiteral("KDirWatch-%1").arg(counter));
 
-    d->_isStopped = false;
-
     if (counter == 1) { // very first KDirWatch instance
         // Must delete QFileSystemWatcher before qApp is gone - bug 261541
         qAddPostRoutine(postRoutine_KDirWatch);
